@@ -13,10 +13,19 @@ set -u
 ### Get data
 #
 VAL_SNOOPY=`$SNOOPY_TEST_DATASOURCE tty_uid`
+if [ "(unknown)" == "$VAL_SNOOPY" ]; then
+    VAL_SNOOPY="(none)"
+fi
+
 if ! tty -s; then
     VAL_REAL="(none)"
 else
-    VAL_REAL=`tty | xargs ls -lan | awk '{print $3}'`
+    VAL_REAL=`tty`
+    if [ "not a tty" == "$VAL_REAL" ]; then
+        VAL_REAL="(none)"
+    else
+        VAL_REAL=`echo "$VAL_REAL" | xargs ls -lan | awk '{print $3}'`
+    fi
 fi
 
 
